.. _sitemap:

******************
PyMVPA.org Sitemap
******************

.. toctree::
   :maxdepth: 2

   whoisusingit
   manual
   datadb
   examples
   faq
   glossary
   changelog
   devguide
   history
   references
   support
   legal
   todo

.. Files which are not directly mentioned in any toctree but
   nevertheless included

..
    toctree::
   :hidden:
   authors
   devguide
   docoverview
   index
   modref

